@@ -5,8 +5,10 @@ module Patat.Presentation
     , Presentation (..)
     , readPresentation
 
+    , activeSpeakerNotes
+
     , Size
-    , getDisplaySize
+    , getPresentationSize
 
     , Display (..)
     , displayPresentation
